@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class GmailSendAsAlias(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-googleworkspace.gmailSendAsAlias.GmailSendAsAlias",
 ):
@@ -30,24 +30,24 @@ class GmailSendAsAlias(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         primary_email: builtins.str,
         send_as_email: builtins.str,
         display_name: typing.Optional[builtins.str] = None,
-        is_default: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        is_default: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         reply_to_address: typing.Optional[builtins.str] = None,
         signature: typing.Optional[builtins.str] = None,
-        smtp_msa: typing.Optional[typing.Union["GmailSendAsAliasSmtpMsa", typing.Dict[str, typing.Any]]] = None,
-        treat_as_alias: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        smtp_msa: typing.Optional[typing.Union["GmailSendAsAliasSmtpMsa", typing.Dict[builtins.str, typing.Any]]] = None,
+        treat_as_alias: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/googleworkspace/r/gmail_send_as_alias googleworkspace_gmail_send_as_alias} Resource.
 
@@ -70,28 +70,7 @@ class GmailSendAsAlias(
         :param provisioners: 
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                primary_email: builtins.str,
-                send_as_email: builtins.str,
-                display_name: typing.Optional[builtins.str] = None,
-                is_default: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                reply_to_address: typing.Optional[builtins.str] = None,
-                signature: typing.Optional[builtins.str] = None,
-                smtp_msa: typing.Optional[typing.Union[GmailSendAsAliasSmtpMsa, typing.Dict[str, typing.Any]]] = None,
-                treat_as_alias: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
-                count: typing.Optional[jsii.Number] = None,
-                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-                provider: typing.Optional[cdktf.TerraformProvider] = None,
-                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7ccaefa5ab7e2e0116d07aeff50c57b1c4d830b8c31331007f0168fcf7ce28a6)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         config = GmailSendAsAliasConfig(
@@ -181,8 +160,8 @@ class GmailSendAsAlias(
 
     @builtins.property
     @jsii.member(jsii_name="isPrimary")
-    def is_primary(self) -> cdktf.IResolvable:
-        return typing.cast(cdktf.IResolvable, jsii.get(self, "isPrimary"))
+    def is_primary(self) -> _cdktf_9a9027ec.IResolvable:
+        return typing.cast(_cdktf_9a9027ec.IResolvable, jsii.get(self, "isPrimary"))
 
     @builtins.property
     @jsii.member(jsii_name="smtpMsa")
@@ -203,8 +182,8 @@ class GmailSendAsAlias(
     @jsii.member(jsii_name="isDefaultInput")
     def is_default_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "isDefaultInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "isDefaultInput"))
 
     @builtins.property
     @jsii.member(jsii_name="primaryEmailInput")
@@ -235,8 +214,8 @@ class GmailSendAsAlias(
     @jsii.member(jsii_name="treatAsAliasInput")
     def treat_as_alias_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "treatAsAliasInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "treatAsAliasInput"))
 
     @builtins.property
     @jsii.member(jsii_name="displayName")
@@ -246,23 +225,22 @@ class GmailSendAsAlias(
     @display_name.setter
     def display_name(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1b992ab897ebaee50668cd8f72ab56c2ccd0743acf8b7514f4c8747b23d8d3ea)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "displayName", value)
 
     @builtins.property
     @jsii.member(jsii_name="isDefault")
-    def is_default(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "isDefault"))
+    def is_default(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "isDefault"))
 
     @is_default.setter
-    def is_default(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+    def is_default(
+        self,
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+    ) -> None:
         if __debug__:
-            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__5a84931a3fe86cf083d53a6ef544e4f9327580827a9eee722dcde98ec59b4944)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "isDefault", value)
 
@@ -274,9 +252,7 @@ class GmailSendAsAlias(
     @primary_email.setter
     def primary_email(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ecf5357cfa5d8c6bc110bff45d7b58bb02520cce802723be8303ba2ca21ba353)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "primaryEmail", value)
 
@@ -288,9 +264,7 @@ class GmailSendAsAlias(
     @reply_to_address.setter
     def reply_to_address(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6e6210b541c6433d644a91b53454e9472cc42ac486e5b93fb08ffda2a6781bf5)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "replyToAddress", value)
 
@@ -302,9 +276,7 @@ class GmailSendAsAlias(
     @send_as_email.setter
     def send_as_email(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__858c62cc7d4e5560d9ba39b44e63b207240d210030bbd8cd1fb938166c9ce062)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sendAsEmail", value)
 
@@ -316,33 +288,31 @@ class GmailSendAsAlias(
     @signature.setter
     def signature(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4f2eefe3f2a58cb47850cefc4cf318ef6e928dd70dfbd1b8ced233d5ac4bccbd)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "signature", value)
 
     @builtins.property
     @jsii.member(jsii_name="treatAsAlias")
-    def treat_as_alias(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "treatAsAlias"))
+    def treat_as_alias(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "treatAsAlias"))
 
     @treat_as_alias.setter
     def treat_as_alias(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            def stub(value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__15bc870e180d1525162dd3d37b5f1866525c66cea9c303687cc81178e4421830)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "treatAsAlias", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-googleworkspace.gmailSendAsAlias.GmailSendAsAliasConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -361,25 +331,25 @@ class GmailSendAsAlias(
         "treat_as_alias": "treatAsAlias",
     },
 )
-class GmailSendAsAliasConfig(cdktf.TerraformMetaArguments):
+class GmailSendAsAliasConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         primary_email: builtins.str,
         send_as_email: builtins.str,
         display_name: typing.Optional[builtins.str] = None,
-        is_default: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        is_default: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         reply_to_address: typing.Optional[builtins.str] = None,
         signature: typing.Optional[builtins.str] = None,
-        smtp_msa: typing.Optional[typing.Union["GmailSendAsAliasSmtpMsa", typing.Dict[str, typing.Any]]] = None,
-        treat_as_alias: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        smtp_msa: typing.Optional[typing.Union["GmailSendAsAliasSmtpMsa", typing.Dict[builtins.str, typing.Any]]] = None,
+        treat_as_alias: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     ) -> None:
         '''
         :param connection: 
@@ -399,30 +369,11 @@ class GmailSendAsAliasConfig(cdktf.TerraformMetaArguments):
         :param treat_as_alias: Defaults to ``true``. Whether Gmail should treat this address as an alias for the user's primary email address. This setting only applies to custom 'from' aliases. See https://support.google.com/a/answer/1710338 for help on making this decision Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace/r/gmail_send_as_alias#treat_as_alias GmailSendAsAlias#treat_as_alias}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(smtp_msa, dict):
             smtp_msa = GmailSendAsAliasSmtpMsa(**smtp_msa)
         if __debug__:
-            def stub(
-                *,
-                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
-                count: typing.Optional[jsii.Number] = None,
-                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-                provider: typing.Optional[cdktf.TerraformProvider] = None,
-                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-                primary_email: builtins.str,
-                send_as_email: builtins.str,
-                display_name: typing.Optional[builtins.str] = None,
-                is_default: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-                reply_to_address: typing.Optional[builtins.str] = None,
-                signature: typing.Optional[builtins.str] = None,
-                smtp_msa: typing.Optional[typing.Union[GmailSendAsAliasSmtpMsa, typing.Dict[str, typing.Any]]] = None,
-                treat_as_alias: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ad61f37f2b22138d22e4742228a80225a7f86ce76ff879a7daa510a3233a9a9d)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -438,7 +389,7 @@ class GmailSendAsAliasConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument signature", value=signature, expected_type=type_hints["signature"])
             check_type(argname="argument smtp_msa", value=smtp_msa, expected_type=type_hints["smtp_msa"])
             check_type(argname="argument treat_as_alias", value=treat_as_alias, expected_type=type_hints["treat_as_alias"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "primary_email": primary_email,
             "send_as_email": send_as_email,
         }
@@ -472,12 +423,12 @@ class GmailSendAsAliasConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -488,46 +439,48 @@ class GmailSendAsAliasConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def primary_email(self) -> builtins.str:
@@ -563,7 +516,7 @@ class GmailSendAsAliasConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def is_default(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Whether this address is selected as the default 'From:' address in situations such as composing a new message or sending a vacation auto-reply.
 
         Every Gmail account has exactly one default send-as address, so the only legal value that clients may write to this field is true. Changing this from false to true for an address will result in this field becoming false for the other previous default address. Toggling an existing alias' default to false is not possible, another alias must be added/imported and toggled to true to remove the default from an existing alias. To avoid drift with Terraform, please change the previous default's config to false AFTER a new default is applied and perform a refresh to synchronize with remote state.
@@ -571,7 +524,7 @@ class GmailSendAsAliasConfig(cdktf.TerraformMetaArguments):
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace/r/gmail_send_as_alias#is_default GmailSendAsAlias#is_default}
         '''
         result = self._values.get("is_default")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def reply_to_address(self) -> typing.Optional[builtins.str]:
@@ -607,7 +560,7 @@ class GmailSendAsAliasConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def treat_as_alias(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Defaults to ``true``.
 
         Whether Gmail should treat this address as an alias for the user's primary email address. This setting only applies to custom 'from' aliases. See https://support.google.com/a/answer/1710338 for help on making this decision
@@ -615,7 +568,7 @@ class GmailSendAsAliasConfig(cdktf.TerraformMetaArguments):
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace/r/gmail_send_as_alias#treat_as_alias GmailSendAsAlias#treat_as_alias}
         '''
         result = self._values.get("treat_as_alias")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -658,22 +611,13 @@ class GmailSendAsAliasSmtpMsa:
         :param username: The username that will be used for authentication with the SMTP service. This is a write-only field that can be specified in requests to create or update SendAs settings; it is never populated in responses. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace/r/gmail_send_as_alias#username GmailSendAsAlias#username}
         '''
         if __debug__:
-            def stub(
-                *,
-                host: builtins.str,
-                port: jsii.Number,
-                password: typing.Optional[builtins.str] = None,
-                security_mode: typing.Optional[builtins.str] = None,
-                username: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__401cb67c55d791db3d1ab76a9f620ce31ea45168de561d0595472b120b23e8cd)
             check_type(argname="argument host", value=host, expected_type=type_hints["host"])
             check_type(argname="argument port", value=port, expected_type=type_hints["port"])
             check_type(argname="argument password", value=password, expected_type=type_hints["password"])
             check_type(argname="argument security_mode", value=security_mode, expected_type=type_hints["security_mode"])
             check_type(argname="argument username", value=username, expected_type=type_hints["username"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "host": host,
             "port": port,
         }
@@ -748,13 +692,13 @@ class GmailSendAsAliasSmtpMsa:
 
 
 class GmailSendAsAliasSmtpMsaOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-googleworkspace.gmailSendAsAlias.GmailSendAsAliasSmtpMsaOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -762,12 +706,7 @@ class GmailSendAsAliasSmtpMsaOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            def stub(
-                terraform_resource: cdktf.IInterpolatingParent,
-                terraform_attribute: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__b8fc5a7abfc566ea371b8bf1b82e459eae7ddf75a9abf23a2d4d7a83be7b863b)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -817,9 +756,7 @@ class GmailSendAsAliasSmtpMsaOutputReference(
     @host.setter
     def host(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c79e0bf0d21ea1f0e1e737e4c474b71c48ecfd23bcd7b6be016843c935aa34ee)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "host", value)
 
@@ -831,9 +768,7 @@ class GmailSendAsAliasSmtpMsaOutputReference(
     @password.setter
     def password(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__17fc3f71561dbe39e4ef0d4c7942bb397faac67914d34be6b0c717c77e78464a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "password", value)
 
@@ -845,9 +780,7 @@ class GmailSendAsAliasSmtpMsaOutputReference(
     @port.setter
     def port(self, value: jsii.Number) -> None:
         if __debug__:
-            def stub(value: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4a9e5ea3239dbc34d19dd1763151c49a1fafd59208cb10c67d6b3a884147697c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "port", value)
 
@@ -859,9 +792,7 @@ class GmailSendAsAliasSmtpMsaOutputReference(
     @security_mode.setter
     def security_mode(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__0200d42305fe10b38bba7e91c70b4e862d1dac7ea5a6c8420c087b39beed2dc0)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "securityMode", value)
 
@@ -873,9 +804,7 @@ class GmailSendAsAliasSmtpMsaOutputReference(
     @username.setter
     def username(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__795268cc71219974b37b4fcc0eb1e387bc48ba0555f4e1854eed9b793067872a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "username", value)
 
@@ -887,9 +816,7 @@ class GmailSendAsAliasSmtpMsaOutputReference(
     @internal_value.setter
     def internal_value(self, value: typing.Optional[GmailSendAsAliasSmtpMsa]) -> None:
         if __debug__:
-            def stub(value: typing.Optional[GmailSendAsAliasSmtpMsa]) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__e78210bc755cbc880e40443c06806dd12e14306cd65d3e91dd6e3de93b10a359)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -902,3 +829,143 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__7ccaefa5ab7e2e0116d07aeff50c57b1c4d830b8c31331007f0168fcf7ce28a6(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    primary_email: builtins.str,
+    send_as_email: builtins.str,
+    display_name: typing.Optional[builtins.str] = None,
+    is_default: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    reply_to_address: typing.Optional[builtins.str] = None,
+    signature: typing.Optional[builtins.str] = None,
+    smtp_msa: typing.Optional[typing.Union[GmailSendAsAliasSmtpMsa, typing.Dict[builtins.str, typing.Any]]] = None,
+    treat_as_alias: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1b992ab897ebaee50668cd8f72ab56c2ccd0743acf8b7514f4c8747b23d8d3ea(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5a84931a3fe86cf083d53a6ef544e4f9327580827a9eee722dcde98ec59b4944(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ecf5357cfa5d8c6bc110bff45d7b58bb02520cce802723be8303ba2ca21ba353(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6e6210b541c6433d644a91b53454e9472cc42ac486e5b93fb08ffda2a6781bf5(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__858c62cc7d4e5560d9ba39b44e63b207240d210030bbd8cd1fb938166c9ce062(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4f2eefe3f2a58cb47850cefc4cf318ef6e928dd70dfbd1b8ced233d5ac4bccbd(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__15bc870e180d1525162dd3d37b5f1866525c66cea9c303687cc81178e4421830(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ad61f37f2b22138d22e4742228a80225a7f86ce76ff879a7daa510a3233a9a9d(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    primary_email: builtins.str,
+    send_as_email: builtins.str,
+    display_name: typing.Optional[builtins.str] = None,
+    is_default: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    reply_to_address: typing.Optional[builtins.str] = None,
+    signature: typing.Optional[builtins.str] = None,
+    smtp_msa: typing.Optional[typing.Union[GmailSendAsAliasSmtpMsa, typing.Dict[builtins.str, typing.Any]]] = None,
+    treat_as_alias: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__401cb67c55d791db3d1ab76a9f620ce31ea45168de561d0595472b120b23e8cd(
+    *,
+    host: builtins.str,
+    port: jsii.Number,
+    password: typing.Optional[builtins.str] = None,
+    security_mode: typing.Optional[builtins.str] = None,
+    username: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b8fc5a7abfc566ea371b8bf1b82e459eae7ddf75a9abf23a2d4d7a83be7b863b(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c79e0bf0d21ea1f0e1e737e4c474b71c48ecfd23bcd7b6be016843c935aa34ee(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__17fc3f71561dbe39e4ef0d4c7942bb397faac67914d34be6b0c717c77e78464a(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4a9e5ea3239dbc34d19dd1763151c49a1fafd59208cb10c67d6b3a884147697c(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0200d42305fe10b38bba7e91c70b4e862d1dac7ea5a6c8420c087b39beed2dc0(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__795268cc71219974b37b4fcc0eb1e387bc48ba0555f4e1854eed9b793067872a(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e78210bc755cbc880e40443c06806dd12e14306cd65d3e91dd6e3de93b10a359(
+    value: typing.Optional[GmailSendAsAliasSmtpMsa],
+) -> None:
+    """Type checking stubs"""
+    pass
