@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class GroupMembers(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-googleworkspace.groupMembers.GroupMembers",
 ):
@@ -30,18 +30,18 @@ class GroupMembers(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         group_id: builtins.str,
-        members: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["GroupMembersMembers", typing.Dict[str, typing.Any]]]]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        members: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["GroupMembersMembers", typing.Dict[builtins.str, typing.Any]]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/googleworkspace/r/group_members googleworkspace_group_members} Resource.
 
@@ -58,22 +58,7 @@ class GroupMembers(
         :param provisioners: 
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                group_id: builtins.str,
-                members: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[GroupMembersMembers, typing.Dict[str, typing.Any]]]]] = None,
-                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
-                count: typing.Optional[jsii.Number] = None,
-                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-                provider: typing.Optional[cdktf.TerraformProvider] = None,
-                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__a98bdeab906eb606ee9cae66f5695ba2abc83bf5e1f651447f63bbc596364231)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         config = GroupMembersConfig(
@@ -93,17 +78,13 @@ class GroupMembers(
     @jsii.member(jsii_name="putMembers")
     def put_members(
         self,
-        value: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["GroupMembersMembers", typing.Dict[str, typing.Any]]]],
+        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["GroupMembersMembers", typing.Dict[builtins.str, typing.Any]]]],
     ) -> None:
         '''
         :param value: -
         '''
         if __debug__:
-            def stub(
-                value: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[GroupMembersMembers, typing.Dict[str, typing.Any]]]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1fe636fded937c94681ec16fec9e860036dd80a8eccc5d59cff636308322c867)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(None, jsii.invoke(self, "putMembers", [value]))
 
@@ -144,8 +125,8 @@ class GroupMembers(
     @jsii.member(jsii_name="membersInput")
     def members_input(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["GroupMembersMembers"]]]:
-        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["GroupMembersMembers"]]], jsii.get(self, "membersInput"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["GroupMembersMembers"]]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["GroupMembersMembers"]]], jsii.get(self, "membersInput"))
 
     @builtins.property
     @jsii.member(jsii_name="groupId")
@@ -155,16 +136,14 @@ class GroupMembers(
     @group_id.setter
     def group_id(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d2cac95223b8c94aa9ba13be68029734731152dd7063c94c875f5a3e2ecad162)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "groupId", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-googleworkspace.groupMembers.GroupMembersConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -177,19 +156,19 @@ class GroupMembers(
         "members": "members",
     },
 )
-class GroupMembersConfig(cdktf.TerraformMetaArguments):
+class GroupMembersConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         group_id: builtins.str,
-        members: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["GroupMembersMembers", typing.Dict[str, typing.Any]]]]] = None,
+        members: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["GroupMembersMembers", typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''
         :param connection: 
@@ -203,22 +182,9 @@ class GroupMembersConfig(cdktf.TerraformMetaArguments):
         :param members: members block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace/r/group_members#members GroupMembers#members}
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            def stub(
-                *,
-                connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
-                count: typing.Optional[jsii.Number] = None,
-                depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-                for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-                lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-                provider: typing.Optional[cdktf.TerraformProvider] = None,
-                provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
-                group_id: builtins.str,
-                members: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union[GroupMembersMembers, typing.Dict[str, typing.Any]]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__a7324ea6ab584c1852e3d0b497aec340920bc1adc90f83313de2994669286ca9)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -228,7 +194,7 @@ class GroupMembersConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument provisioners", value=provisioners, expected_type=type_hints["provisioners"])
             check_type(argname="argument group_id", value=group_id, expected_type=type_hints["group_id"])
             check_type(argname="argument members", value=members, expected_type=type_hints["members"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "group_id": group_id,
         }
         if connection is not None:
@@ -251,12 +217,12 @@ class GroupMembersConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -267,46 +233,48 @@ class GroupMembersConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def group_id(self) -> builtins.str:
@@ -323,13 +291,13 @@ class GroupMembersConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def members(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["GroupMembersMembers"]]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["GroupMembersMembers"]]]:
         '''members block.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace/r/group_members#members GroupMembers#members}
         '''
         result = self._values.get("members")
-        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["GroupMembersMembers"]]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["GroupMembersMembers"]]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -369,20 +337,12 @@ class GroupMembersMembers:
         :param type: Defaults to ``USER``. The type of group member. Acceptable values are: - ``CUSTOMER``: The member represents all users in a domain. An email address is not returned and the ID returned is the customer ID. - ``GROUP``: The member is another group. - ``USER``: The member is a user. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace/r/group_members#type GroupMembers#type}
         '''
         if __debug__:
-            def stub(
-                *,
-                email: builtins.str,
-                delivery_settings: typing.Optional[builtins.str] = None,
-                role: typing.Optional[builtins.str] = None,
-                type: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7965971c3835dfd95742a1ed8eb53ca6c8bfc206a8aa8c299cd59ef2d690feb2)
             check_type(argname="argument email", value=email, expected_type=type_hints["email"])
             check_type(argname="argument delivery_settings", value=delivery_settings, expected_type=type_hints["delivery_settings"])
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "email": email,
         }
         if delivery_settings is not None:
@@ -464,13 +424,13 @@ class GroupMembersMembers:
 
 
 class GroupMembersMembersList(
-    cdktf.ComplexList,
+    _cdktf_9a9027ec.ComplexList,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-googleworkspace.groupMembers.GroupMembersMembersList",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
         wraps_set: builtins.bool,
     ) -> None:
@@ -480,13 +440,7 @@ class GroupMembersMembersList(
         :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            def stub(
-                terraform_resource: cdktf.IInterpolatingParent,
-                terraform_attribute: builtins.str,
-                wraps_set: builtins.bool,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__59348f5e2387936001312c26551b893073729a68e7bd72de72ceaf5956415444)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
@@ -498,9 +452,7 @@ class GroupMembersMembersList(
         :param index: the index of the item to return.
         '''
         if __debug__:
-            def stub(index: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__dccff58f374defb85acb0ae5b6c0e4a083ef5a3de253e23e0517ec1a651a86a3)
             check_type(argname="argument index", value=index, expected_type=type_hints["index"])
         return typing.cast("GroupMembersMembersOutputReference", jsii.invoke(self, "get", [index]))
 
@@ -513,24 +465,20 @@ class GroupMembersMembersList(
     @_terraform_attribute.setter
     def _terraform_attribute(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__57efb0aae012e5da21dbe895e9a6622a3ea72e9e8ff3764798b31861b131847c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformAttribute", value)
 
     @builtins.property
     @jsii.member(jsii_name="terraformResource")
-    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
+    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
         '''The parent resource.'''
-        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))
+        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))
 
     @_terraform_resource.setter
-    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
+    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
         if __debug__:
-            def stub(value: cdktf.IInterpolatingParent) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__88eceeb21436510961c5124525c7a650753dc1d801e9067edc487e804ab22100)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformResource", value)
 
@@ -543,9 +491,7 @@ class GroupMembersMembersList(
     @_wraps_set.setter
     def _wraps_set(self, value: builtins.bool) -> None:
         if __debug__:
-            def stub(value: builtins.bool) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__2d17216a25ea5166154631791f403928cd1e8d87a7cff7758dbc0a3ca85899b8)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "wrapsSet", value)
 
@@ -553,32 +499,28 @@ class GroupMembersMembersList(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[GroupMembersMembers]]]:
-        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[GroupMembersMembers]]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[GroupMembersMembers]]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[GroupMembersMembers]]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[GroupMembersMembers]]],
+        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[GroupMembersMembers]]],
     ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[GroupMembersMembers]]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__564563b5989e3859ba9d6a172f5c3963de485ba517cedde902008b9b1ea72520)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
 
 class GroupMembersMembersOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-googleworkspace.groupMembers.GroupMembersMembersOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
         complex_object_index: jsii.Number,
         complex_object_is_from_set: builtins.bool,
@@ -590,14 +532,7 @@ class GroupMembersMembersOutputReference(
         :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            def stub(
-                terraform_resource: cdktf.IInterpolatingParent,
-                terraform_attribute: builtins.str,
-                complex_object_index: jsii.Number,
-                complex_object_is_from_set: builtins.bool,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8942b50b3365c7a2f53b4ae696adc6949d004bae55a878b7a33560dd256d94bc)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
@@ -654,9 +589,7 @@ class GroupMembersMembersOutputReference(
     @delivery_settings.setter
     def delivery_settings(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f003e12b8604fe1187ed76d238ee7dc341eefd80794accb0d7d558fe33e1ea71)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "deliverySettings", value)
 
@@ -668,9 +601,7 @@ class GroupMembersMembersOutputReference(
     @email.setter
     def email(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ad08b643f251fa27d97e9b9b3ad3dd175e4c4be3a7b32a472f36a0d5455ac48d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "email", value)
 
@@ -682,9 +613,7 @@ class GroupMembersMembersOutputReference(
     @role.setter
     def role(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__9a7757c0af9ad7530f91a0bad4a0987a00e8f724554cb66df6b197b407fcead5)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "role", value)
 
@@ -696,9 +625,7 @@ class GroupMembersMembersOutputReference(
     @type.setter
     def type(self, value: builtins.str) -> None:
         if __debug__:
-            def stub(value: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__72cd3de5477721535a7885e15cb1f928ba439af3aedcfdc74f4ce3689d3aeb9b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "type", value)
 
@@ -706,20 +633,16 @@ class GroupMembersMembersOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[GroupMembersMembers, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[GroupMembersMembers, cdktf.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[GroupMembersMembers, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[GroupMembersMembers, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[GroupMembersMembers, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[GroupMembersMembers, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            def stub(
-                value: typing.Optional[typing.Union[GroupMembersMembers, cdktf.IResolvable]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__9e6f74ef246e9613b11764b872f63e2ab03f680c26ca4a3d66bf6b54a6bb378a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -733,3 +656,134 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__a98bdeab906eb606ee9cae66f5695ba2abc83bf5e1f651447f63bbc596364231(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    group_id: builtins.str,
+    members: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[GroupMembersMembers, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1fe636fded937c94681ec16fec9e860036dd80a8eccc5d59cff636308322c867(
+    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[GroupMembersMembers, typing.Dict[builtins.str, typing.Any]]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d2cac95223b8c94aa9ba13be68029734731152dd7063c94c875f5a3e2ecad162(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a7324ea6ab584c1852e3d0b497aec340920bc1adc90f83313de2994669286ca9(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    group_id: builtins.str,
+    members: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[GroupMembersMembers, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7965971c3835dfd95742a1ed8eb53ca6c8bfc206a8aa8c299cd59ef2d690feb2(
+    *,
+    email: builtins.str,
+    delivery_settings: typing.Optional[builtins.str] = None,
+    role: typing.Optional[builtins.str] = None,
+    type: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__59348f5e2387936001312c26551b893073729a68e7bd72de72ceaf5956415444(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+    wraps_set: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__dccff58f374defb85acb0ae5b6c0e4a083ef5a3de253e23e0517ec1a651a86a3(
+    index: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__57efb0aae012e5da21dbe895e9a6622a3ea72e9e8ff3764798b31861b131847c(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__88eceeb21436510961c5124525c7a650753dc1d801e9067edc487e804ab22100(
+    value: _cdktf_9a9027ec.IInterpolatingParent,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2d17216a25ea5166154631791f403928cd1e8d87a7cff7758dbc0a3ca85899b8(
+    value: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__564563b5989e3859ba9d6a172f5c3963de485ba517cedde902008b9b1ea72520(
+    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[GroupMembersMembers]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8942b50b3365c7a2f53b4ae696adc6949d004bae55a878b7a33560dd256d94bc(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+    complex_object_index: jsii.Number,
+    complex_object_is_from_set: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f003e12b8604fe1187ed76d238ee7dc341eefd80794accb0d7d558fe33e1ea71(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ad08b643f251fa27d97e9b9b3ad3dd175e4c4be3a7b32a472f36a0d5455ac48d(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9a7757c0af9ad7530f91a0bad4a0987a00e8f724554cb66df6b197b407fcead5(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__72cd3de5477721535a7885e15cb1f928ba439af3aedcfdc74f4ce3689d3aeb9b(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9e6f74ef246e9613b11764b872f63e2ab03f680c26ca4a3d66bf6b54a6bb378a(
+    value: typing.Optional[typing.Union[GroupMembersMembers, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
